import{d as c,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.84fe9cdf.js";import"./router.55b997dc.js";import"./index.46fac088.js";import{O as w}from"./organization.03c05399.js";import{a as k}from"./asyncComputed.6b982433.js";import{A}from"./Title.59475fea.js";import{A as B}from"./index.7b2adc4e.js";import{A as h}from"./index.b4b3d5fe.js";import{A as C}from"./Text.6c3b9f60.js";import{C as v}from"./Card.b3863c0d.js";import"./FormItem.3f0afd7c.js";import"./hasIn.892e96d0.js";import"./index.cf4c23b9.js";import"./record.d584e714.js";import"./pubsub.e099f5f1.js";import"./Base.3448c1ef.js";import"./TabPane.dfbe23a9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="23728378-f1fa-4fe2-944c-6a8e086bfea4",t._sentryDebugIdIdentifier="sentry-dbid-23728378-f1fa-4fe2-944c-6a8e086bfea4")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},Q=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:f,result:l}=k(()=>w.get(n));return(z,N)=>e(f)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",I,x((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{Q as default};
//# sourceMappingURL=Billing.04afd159.js.map
