import{ac as p,V as t,Q as a,f}from"./outputWidgets.84fe9cdf.js";import{B as l,b}from"./Base.3448c1ef.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="b3da8035-4e3d-4351-b3f4-dd424690e322",e._sentryDebugIdIdentifier="sentry-dbid-b3da8035-4e3d-4351-b3f4-dd424690e322")}catch{}})();const c=()=>t(t({},a(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:d,attrs:r}=s;const{ellipsis:n}=e;p();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?a(n,["expandable","rows"]):n,component:"span"}),r);return f(l,i,d)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=c();const g=o;export{g as A};
//# sourceMappingURL=Text.6c3b9f60.js.map
