import{a as m}from"./api.0b487b10.js";import{P as c}from"./Passwordless.94310c84.js";import{a as f}from"./asyncComputed.6b982433.js";import{W as p}from"./WidgetsFrame.bef91c2b.js";import{d as u,eA as l,eB as _,b as i,ev as y,e as b,u as a,c as g,w as h,ex as w,f as v,v as k}from"./outputWidgets.84fe9cdf.js";import"./runnerData.17301334.js";import"./url.8de5cd7a.js";import"./index.72d3c468.js";import"./pubsub.e099f5f1.js";import"./icons.fb80f0dd.js";import"./CircularLoading.da6d195c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="498f1500-0aeb-4431-ae36-bbea65eea71f",e._sentryDebugIdIdentifier="sentry-dbid-498f1500-0aeb-4431-ae36-bbea65eea71f")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=f(m),d=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[b("div",x,[a(o)?(i(),g(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(c,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.9769b780.js.map
