import{e9 as i,ac as p,V as s,f as d,Q as b}from"./outputWidgets.84fe9cdf.js";import{B as y,b as u}from"./Base.3448c1ef.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c92c9dd9-e23f-427e-ac9f-2cba6e93738b",e._sentryDebugIdIdentifier="sentry-dbid-c92c9dd9-e23f-427e-ac9f-2cba6e93738b")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=i(1,2,3,4,5),_=()=>s(s({},b(u(),["component","strong"])),{level:Number}),l=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,c=g(e,["level"]);let a;m.includes(r)?a=`h${r}`:(p(),a="h1");const f=s(s(s({},c),{component:a}),t);return d(y,f,n)};l.displayName="ATypographyTitle";l.inheritAttrs=!1;l.props=_();const w=l;export{w as A};
//# sourceMappingURL=Title.59475fea.js.map
