import"./outputWidgets.84fe9cdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9e30c4fe-f614-4ba4-9b0d-739ce8151bfa",e._sentryDebugIdIdentifier="sentry-dbid-9e30c4fe-f614-4ba4-9b0d-739ce8151bfa")}catch{}})();function l(e,n,o=!1,t=!0){const r=(t?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=o?r:r.replace(/_+/g,"_");return n?c:c.replace(/_$/,"")}function d(e){var r;const o=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,a=o.match(t);return(r=a==null?void 0:a.join("-"))!=null?r:""}export{d as a,l as n};
//# sourceMappingURL=string.c5b719a8.js.map
