import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.f598d46b.js";import{K as d,P as b,L as l}from"./repository.3c2ab0bd.js";import{d as u,b as f,ev as c,f as p,u as r}from"./outputWidgets.84fe9cdf.js";import{u as g}from"./index.72d3c468.js";import{a as y}from"./asyncComputed.6b982433.js";import{a as _}from"./api.0b487b10.js";import"./Text.6c3b9f60.js";import"./Base.3448c1ef.js";import"./index.69c8862c.js";import"./Link.10affec7.js";import"./Paragraph.7a7aafbc.js";import"./Title.59475fea.js";import"./index.f71c4aee.js";import"./ant-design.53be314d.js";import"./index.0be37f33.js";import"./Modal.47a21763.js";import"./metadata.8eebc80b.js";import"./icons.fb80f0dd.js";import"./index.7b2adc4e.js";import"./index.2424aba1.js";import"./index.dfa7d0bd.js";import"./index.9fb0e57f.js";import"./Card.b3863c0d.js";import"./TabPane.dfbe23a9.js";import"./hasIn.892e96d0.js";import"./CollapsePanel.d4790a2a.js";import"./Form.ff60b0b9.js";import"./FormItem.3f0afd7c.js";import"./Timeline.4055cf34.js";import"./index.e4bca734.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.5bb8274a.js";import"./index.cf4c23b9.js";import"./scripts.c6e6d94e.js";import"./record.d584e714.js";import"./pubsub.e099f5f1.js";import"./ExpandOutlined.90406b41.js";import"./runnerData.17301334.js";import"./url.8de5cd7a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="e989ba1e-286d-4447-9427-78a6a7abab05",o._sentryDebugIdIdentifier="sentry-dbid-e989ba1e-286d-4447-9427-78a6a7abab05")}catch{}})();const io=u({__name:"Kanban",setup(o){const t=new b(g),e=new l("kanban"),{result:a}=y(_);return(k,w)=>{var n,i,m;return f(),c("div",null,[p(s,{"brand-name":((n=r(a))==null?void 0:n.brandName)||((i=r(a))==null?void 0:i.name),"logo-url":(m=r(a))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{io as default};
//# sourceMappingURL=Kanban.04bb73fc.js.map
