import"./outputWidgets.84fe9cdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="148e4ff7-d959-4466-b9fd-ba8983b88f1e",e._sentryDebugIdIdentifier="sentry-dbid-148e4ff7-d959-4466-b9fd-ba8983b88f1e")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.8de5cd7a.js.map
