import{v as h,w as k}from"./icons.fb80f0dd.js";import{d as b,H as y,b as a,ev as t,e as o,a$ as f,eC as S,ez as m,eD as v,v as g,G as I,u as _,ex as r,f as R,I as N,c as w,eE as C,eF as $}from"./outputWidgets.84fe9cdf.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[i]="7f84c2ca-306c-4fc7-bd70-04f1d21c800d",s._sentryDebugIdIdentifier="sentry-dbid-7f84c2ca-306c-4fc7-bd70-04f1d21c800d")}catch{}})();const E={class:"sidebar-content"},B={class:"section"},D=["onClick"],P={class:"item-title"},U=b({__name:"Sidebar",props:{currentRuntime:{},displaySidebar:{type:Boolean},forceResponsivity:{}},emits:["selectRuntime","closeSidebar"],setup(s,{emit:i}){const c=s,u=e=>{p(e.id)||i("selectRuntime",e)},d=y(()=>c.currentRuntime.sidebar.filter(e=>e.visible)),p=e=>e===c.currentRuntime.id;return(e,n)=>(a(),t("div",{class:m(["sidebar",e.forceResponsivity,{open:e.displaySidebar}])},[o("div",E,[o("div",B,[(a(!0),t(f,null,S(d.value,l=>(a(),t("div",{key:l.id,class:m(["item",{active:p(l.id)}]),onClick:K=>u(l)},[o("div",P,v(l.name),1)],10,D))),128))])])],2))}});const V=g(U,[["__scopeId","data-v-14a5ac8c"]]),z=s=>(C("data-v-e67cfd1a"),s=s(),$(),s),F={class:"left-side"},G=["d"],H={key:1,class:"brand"},L=["src"],j={key:1,class:"brand-name"},q=z(()=>o("div",null,null,-1)),A={key:0,class:"signed-email"},J=b({__name:"PlayerNavbar",props:{runtime:{},userEmail:{},forceResponsivity:{}},emits:["logout","navigate"],setup(s,{emit:i}){const c=s,u=I({displaySidebar:!1}),d=y(()=>{const e=c.runtime.sidebar;return!e||e.length==0?!1:e.some(n=>n.visible)}),p=e=>i("navigate",e);return(e,n)=>(a(),t(f,null,[d.value||e.runtime.logoUrl||e.runtime.brandName||e.userEmail?(a(),t("div",{key:0,class:m(["navbar",d.value&&"background"])},[o("div",F,[d.value?(a(),t("svg",{key:0,class:m(["sidebar-menu-icon",e.forceResponsivity]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:n[0]||(n[0]=l=>u.displaySidebar=!u.displaySidebar)},[o("path",{d:_(h)},null,8,G)],2)):r("",!0),e.runtime.logoUrl||e.runtime.brandName?(a(),t("div",H,[e.runtime.logoUrl?(a(),t("img",{key:0,src:e.runtime.logoUrl,class:"logo-image"},null,8,L)):r("",!0),e.runtime.brandName?(a(),t("p",j,v(e.runtime.brandName),1)):r("",!0)])):r("",!0)]),q,e.userEmail?(a(),t("div",A,[o("span",null,v(e.userEmail),1),R(N,{width:"20",height:"20",class:"logout",path:_(k),fill:"var(--color-main)",onClick:n[1]||(n[1]=l=>i("logout"))},null,8,["path"])])):r("",!0)],2)):r("",!0),d.value?(a(),w(V,{key:1,"current-runtime":e.runtime,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:p},null,8,["current-runtime","display-sidebar","force-responsivity"])):r("",!0)],64))}});const Q=g(J,[["__scopeId","data-v-e67cfd1a"]]);export{Q as P};
//# sourceMappingURL=PlayerNavbar.bb0f21f0.js.map
