import{d as h,eA as w,eB as k,r as x,H as y,b as n,c as d,w as t,ev as b,eC as I,u as l,bu as C,ez as f,f as s,I as B,ar as N,eD as D,a$ as S,bw as V,v as A,eE as E,eF as L,e as g,a as p,ex as T}from"./outputWidgets.84fe9cdf.js";import{h as $,s as H}from"./icons.fb80f0dd.js";import{_ as z}from"./logo.084e5d7c.js";import{B as F}from"./BaseLayout.62d29ec0.js";import{N as M}from"./NavbarControls.3eea91d6.js";import{c as R}from"./index.f71c4aee.js";import"./asyncComputed.6b982433.js";import"./index.72d3c468.js";import"./pubsub.e099f5f1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.41277f9f.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.48cf43a0.js";import"./ant-design.53be314d.js";import"./index.0be37f33.js";import"./Modal.47a21763.js";import"./Base.3448c1ef.js";import"./Link.10affec7.js";import"./index.dfb164b3.js";import"./Paragraph.7a7aafbc.js";import"./Text.6c3b9f60.js";import"./workspaces.f0c8759d.js";import"./runnerData.17301334.js";import"./url.8de5cd7a.js";import"./record.d584e714.js";import"./popupNotifcation.59b6a17f.js";import"./CircularLoading.da6d195c.js";import"./index.7b2adc4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="cd5609d0-d136-4332-8645-8a168d8b15b0",e._sentryDebugIdIdentifier="sentry-dbid-cd5609d0-d136-4332-8645-8a168d8b15b0")}catch{}})();const W=h({__name:"Sidebar",setup(e){var m;const o=w(),c=k(),r=x((m=c.name)!=null?m:"forms"),u=y(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:H,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),d(l(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(S,null,I(u.value,a=>(n(),d(l(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const P={},v=e=>(E("data-v-81cd596e"),e=e(),L(),e),j={class:"logo"},q=v(()=>g("img",{src:z,alt:"Abstra cloud logo"},null,-1)),G=v(()=>g("span",null," Abstra ",-1)),J=[q,G];function K(e,o){return n(),b("div",j,J)}const O=A(P,[["render",K],["__scopeId","data-v-81cd596e"]]),ye=h({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),d(F,null,{navbar:t(()=>[s(l(R),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(M,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(W,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{ye as default};
//# sourceMappingURL=Workspace.01d6a276.js.map
