import{V as s,f as p,Q as d}from"./outputWidgets.84fe9cdf.js";import{B as f,b as c}from"./Base.3448c1ef.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="0c4faca1-a108-4f66-8a4d-5bbc3d6b1050",a._sentryDebugIdIdentifier="sentry-dbid-0c4faca1-a108-4f66-8a4d-5bbc3d6b1050")}catch{}})();const i=()=>d(c(),["component"]),e=(a,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},a),{component:"div"}),o);return p(f,n,t)};e.displayName="ATypographyParagraph";e.inheritAttrs=!1;e.props=i();const g=e;export{g as A};
//# sourceMappingURL=Paragraph.7a7aafbc.js.map
