import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.f598d46b.js";import{a as p}from"./api.0b487b10.js";import{a as _}from"./asyncComputed.6b982433.js";import{W as y}from"./WidgetsFrame.bef91c2b.js";import{d as b,eB as g,b as n,ev as h,e as a,u as t,c as d,w as v,ex as l,eD as u,v as w}from"./outputWidgets.84fe9cdf.js";import"./index.72d3c468.js";import"./pubsub.e099f5f1.js";import"./Text.6c3b9f60.js";import"./Base.3448c1ef.js";import"./index.69c8862c.js";import"./Link.10affec7.js";import"./Paragraph.7a7aafbc.js";import"./Title.59475fea.js";import"./index.f71c4aee.js";import"./runnerData.17301334.js";import"./url.8de5cd7a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="577fbe8d-009b-488a-95f5-ea37ba496996",o._sentryDebugIdIdentifier="sentry-dbid-577fbe8d-009b-488a-95f5-ea37ba496996")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=b({__name:"Error",setup(o){const r=g(),{result:e}=_(p),i=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),d(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var m,c;return[t(e)?(n(),d(f,{key:0,"brand-name":((m=t(e))==null?void 0:m.brandName)||((c=t(e))==null?void 0:c.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(i().status),1),a("p",null,u(i().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.fbc82bd9.js.map
