import{cz as d}from"./outputWidgets.84fe9cdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="29542921-b43e-4900-a9dc-902efb47bd78",e._sentryDebugIdIdentifier="sentry-dbid-29542921-b43e-4900-a9dc-902efb47bd78")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.59b6a17f.js.map
