import{S as p}from"./Sidebar.5aa7dd4b.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.4e7727c6.js";import{G as d,H as l,I as u}from"./icons.fb80f0dd.js";import{d as f,eB as b,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.84fe9cdf.js";import{a as w}from"./asyncComputed.6b982433.js";import"./router.55b997dc.js";import"./index.46fac088.js";import{O as z}from"./organization.03c05399.js";import{B as I}from"./BaseLayout.62d29ec0.js";import"./index.2424aba1.js";import"./logo.084e5d7c.js";import"./Text.6c3b9f60.js";import"./Base.3448c1ef.js";import"./index.f71c4aee.js";import"./FormItem.3f0afd7c.js";import"./hasIn.892e96d0.js";import"./index.cf4c23b9.js";import"./record.d584e714.js";import"./pubsub.e099f5f1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="2860fc3a-9e18-4977-a939-04f1271084e4",o._sentryDebugIdIdentifier="sentry-dbid-2860fc3a-9e18-4977-a939-04f1271084e4")}catch{}})();const F=f({__name:"Organization",setup(o){const n=b().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{F as default};
//# sourceMappingURL=Organization.0edbd7ab.js.map
