import{a as e,B as s}from"./Base.3448c1ef.js";import{A as t}from"./Link.10affec7.js";import{A as o}from"./Paragraph.7a7aafbc.js";import{A as r}from"./Text.6c3b9f60.js";import{A as i}from"./Title.59475fea.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="6939a483-de74-4b2a-b370-3e569a72f4f4",n._sentryDebugIdIdentifier="sentry-dbid-6939a483-de74-4b2a-b370-3e569a72f4f4")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=t;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,t),n};
//# sourceMappingURL=index.69c8862c.js.map
