import{K as i,E as a,L as s}from"./repository.3c2ab0bd.js";import{d as p,b as m,c,u as e}from"./outputWidgets.84fe9cdf.js";import{l as d}from"./index.72d3c468.js";import"./ant-design.53be314d.js";import"./index.0be37f33.js";import"./Modal.47a21763.js";import"./asyncComputed.6b982433.js";import"./metadata.8eebc80b.js";import"./icons.fb80f0dd.js";import"./index.7b2adc4e.js";import"./index.2424aba1.js";import"./Paragraph.7a7aafbc.js";import"./Base.3448c1ef.js";import"./index.69c8862c.js";import"./Link.10affec7.js";import"./Text.6c3b9f60.js";import"./Title.59475fea.js";import"./index.dfa7d0bd.js";import"./index.9fb0e57f.js";import"./Card.b3863c0d.js";import"./TabPane.dfbe23a9.js";import"./hasIn.892e96d0.js";import"./CollapsePanel.d4790a2a.js";import"./Form.ff60b0b9.js";import"./FormItem.3f0afd7c.js";import"./Timeline.4055cf34.js";import"./index.e4bca734.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.5bb8274a.js";import"./index.cf4c23b9.js";import"./scripts.c6e6d94e.js";import"./record.d584e714.js";import"./pubsub.e099f5f1.js";import"./ExpandOutlined.90406b41.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="b717f0ec-d5e5-4dfa-94e6-08a504bcaa52",t._sentryDebugIdIdentifier="sentry-dbid-b717f0ec-d5e5-4dfa-94e6-08a504bcaa52")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const U=p({__name:"WorkflowKanban",setup(t){const o=new a,r=new f,n=new s("kanban");return(u,b)=>(m(),c(i,{"kanban-repository":e(o),storage:e(n),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{U as default};
//# sourceMappingURL=WorkflowKanban.42b5f5af.js.map
