import{C as t,E as i,K as d,a as c,M as f,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.b68478fe.js";import"./outputWidgets.84fe9cdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2c2d352e-2c08-4991-9427-4cb504ef117e",e._sentryDebugIdIdentifier="sentry-dbid-2c2d352e-2c08-4991-9427-4cb504ef117e")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,c as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.c5b4bee4.js.map
