import{z as e}from"./index.cf4c23b9.js";import"./outputWidgets.84fe9cdf.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="18fe92ad-c121-44bd-ac6a-beb96f91bd16",t._sentryDebugIdIdentifier="sentry-dbid-18fe92ad-c121-44bd-ac6a-beb96f91bd16")}catch{}})();const g=e.boolean(),S=e.boolean(),b=e.boolean(),C=e.boolean();e.object({PROJECT_LIVE:g.optional(),ALLOW_RELEASE:S.optional(),CONNECTORS_CONSOLE:b.optional(),DUPLICATE_PROJECTS:C.optional()});const u=e.string();e.object({plan:u.optional()});const h=e.string(),d=e.string(),A=e.string(),R=e.string(),L=e.null(),y=e.string(),P=e.union([L,y]),O=e.string().regex(new RegExp("^[0-9]+m$")),E=e.string().regex(new RegExp("^[0-9]+m$")),j=e.string().regex(new RegExp("^[0-9]+Mi$")),x=e.string().regex(new RegExp("^[0-9]+Mi$")),D=e.string().regex(new RegExp("^[0-9]+$")),M=e.string().regex(new RegExp("^[0-9]+$")),w=e.enum(["shared","clickbus","test"]),I=e.object({requestsCPU:O.optional(),limitsCPU:E.optional(),requestsMemory:j.optional(),limitsMemory:x.optional(),minReplicas:D.optional(),timeoutSeconds:M.optional(),workerType:w.optional()});e.object({id:h,name:d,subdomain:A,organizationId:R,customDomain:P.optional(),deploymentResources:I.optional()});const z=e.string().regex(new RegExp("^[0-9]+m$")),U=e.string().regex(new RegExp("^[0-9]+m$")),T=e.string().regex(new RegExp("^[0-9]+Mi$")),f=e.string().regex(new RegExp("^[0-9]+Mi$")),_=e.string().regex(new RegExp("^[0-9]+$")),F=e.string().regex(new RegExp("^[0-9]+$")),N=e.enum(["shared","clickbus","test"]);e.object({requestsCPU:z.optional(),limitsCPU:U.optional(),requestsMemory:T.optional(),limitsMemory:f.optional(),minReplicas:_.optional(),timeoutSeconds:F.optional(),workerType:N.optional()});const q=e.string(),n=e.string(),$=e.literal("workflow_viewer"),pt=["workflow_viewer"],o=e.array($),k=e.string(),V=e.string(),W=e.object({id:q,email:n,roles:o,projectId:k,createdAt:V}),s=e.string(),i=e.string(),K=e.boolean(),J=e.boolean(),B=e.boolean(),v=e.boolean(),r=e.object({PROJECT_LIVE:K,ALLOW_RELEASE:J,CONNECTORS_CONSOLE:B,DUPLICATE_PROJECTS:v}),G=e.string(),m=e.object({plan:G.optional()}),Q=e.string().regex(new RegExp("^[0-9]+m$")),H=e.string().regex(new RegExp("^[0-9]+m$")),X=e.string().regex(new RegExp("^[0-9]+Mi$")),Y=e.string().regex(new RegExp("^[0-9]+Mi$")),Z=e.string().regex(new RegExp("^[0-9]+$")),ee=e.string().regex(new RegExp("^[0-9]+$")),te=e.enum(["shared","clickbus","test"]),oe=e.object({requestsCPU:Q.optional(),limitsCPU:H.optional(),requestsMemory:X.optional(),limitsMemory:Y.optional(),minReplicas:Z.optional(),timeoutSeconds:ee.optional(),workerType:te.optional()}),ae=e.string(),ne=e.array(ae),se=e.object({whitelistPatterns:ne.optional()});e.object({id:s,name:i,featureFlags:r,billingMetadata:m,deploymentResources:oe.optional(),membershipsMetadata:se.optional()});const ie=e.string(),re=e.array(ie);e.object({whitelistPatterns:re.optional()});const me=s,ce=i,le=r,pe=m;e.object({id:me,name:ce,featureFlags:le,billingMetadata:pe});const ge=o;e.object({roles:ge});const Se=e.number(),be=e.number();e.object({offset:Se.optional(),limit:be.optional()});const Ce=W;e.array(Ce);const ue=n,he=o;e.object({email:ue,roles:he});const de=e.boolean();e.object({shouldBeOnboarded:de.optional()});const Ae=e.string(),Re=e.string(),Le=e.string(),ye=e.string();e.object({name:Ae.optional(),companyName:Re.optional(),source:Le.optional(),authorEmail:ye.optional()});const Pe=e.string(),Oe=e.record(e.any()),Ee=e.string(),je=e.object({key:Pe,value:Oe,type:Ee}),xe=je,De=e.array(xe),Me=e.string(),we=e.enum(["text","image","table","progress-bar"]),Ie=e.object({name:Me,type:we}),ze=e.string(),Ue=e.string(),Te=e.record(e.any()),c=e.enum(["waiting","running","finished","failed","abandoned"]),gt=["waiting","running","finished","failed","abandoned"],fe=e.string(),_e=e.string(),Fe=e.string();e.object({id:ze,stage:Ue,data:Te,status:c,created_at:fe,parent_id:_e.optional(),execution_id:Fe.optional()});const Ne=e.string(),qe=e.string(),$e=e.string(),ke=c,Ve=De,We=e.object({id:Ne,created_at:qe,assignee:$e.optional(),status:ke,content:Ve}),Ke=We,Je=e.array(Ke),Be=e.string(),ve=e.enum(["form","hook","job","script","iterator","condition"]),Ge=e.string(),Qe=e.string(),He=e.boolean(),l=e.object({id:Be,type:ve,title:Ge,path:Qe.optional(),can_be_started:He}),Xe=l,Ye=Je,Ze=l,p=e.array(Ze),et=p,tt=e.number(),ot=e.object({selected_stage:Xe,stage_run_cards:Ye,stages:et,total_count:tt}),at=ot,nt=e.array(at),st=nt,it=p;e.object({columns:st,next_stage_options:it});const rt=Ie;e.array(rt);export{gt as A,pt as C};
//# sourceMappingURL=contracts.generated.5bb8274a.js.map
