import"./outputWidgets.84fe9cdf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e14ec78b-ea13-45c6-8ece-e185496ee7cf",e._sentryDebugIdIdentifier="sentry-dbid-e14ec78b-ea13-45c6-8ece-e185496ee7cf")}catch{}})();function d(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{d as g};
//# sourceMappingURL=datetime.c91a1385.js.map
