.form-preview-container[data-v-3582c0df]{height:calc(100vh - 200px);min-height:500px;border-radius:10px;overflow:hidden;margin-top:20px}.description[data-v-a8ca44f6]{margin-bottom:20px;font-style:italic;display:block}
