import{V as s}from"./outputWidgets.84fe9cdf.js";import{c as i,d}from"./index.3ad2a3cc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="e6a630a1-981c-4c52-9582-8fe5c747d14b",e._sentryDebugIdIdentifier="sentry-dbid-e6a630a1-981c-4c52-9582-8fe5c747d14b")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=i(d),b=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.68dd5679.js.map
