import{N as l}from"./NavbarControls.3eea91d6.js";import{d as f,eA as _,eB as y,H as g,a as v,b as c,ev as h,f as e,w as s,u as a,e as k,a$ as w,ar as S,c as x,eS as q,v as A}from"./outputWidgets.84fe9cdf.js";import{A as B}from"./Text.6c3b9f60.js";import{T as C,A as o}from"./TabPane.dfbe23a9.js";import{c as I}from"./index.f71c4aee.js";import"./asyncComputed.6b982433.js";import"./index.72d3c468.js";import"./pubsub.e099f5f1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.41277f9f.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.48cf43a0.js";import"./ant-design.53be314d.js";import"./index.0be37f33.js";import"./Modal.47a21763.js";import"./Base.3448c1ef.js";import"./Link.10affec7.js";import"./index.dfb164b3.js";import"./Paragraph.7a7aafbc.js";import"./workspaces.f0c8759d.js";import"./runnerData.17301334.js";import"./url.8de5cd7a.js";import"./record.d584e714.js";import"./popupNotifcation.59b6a17f.js";import"./CircularLoading.da6d195c.js";import"./icons.fb80f0dd.js";import"./index.7b2adc4e.js";import"./hasIn.892e96d0.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="2eefbef0-3c55-49ab-81eb-d07254cc5ab0",r._sentryDebugIdIdentifier="sentry-dbid-2eefbef0-3c55-49ab-81eb-d07254cc5ab0")}catch{}})();const T={class:"content"},D=f({__name:"Settings",setup(r){const t=_(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(B),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:b})=>[(c(),x(q(b)))]),_:1})])],64)}}});const oe=A(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.25cc8993.js.map
