import{r as o,w as n}from"./runnerData.17301334.js";import"./outputWidgets.84fe9cdf.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="9e777dfb-1feb-46b3-9405-dc756d9237d1",t._sentryDebugIdIdentifier="sentry-dbid-9e777dfb-1feb-46b3-9405-dc756d9237d1")}catch{}})();async function d(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:r}=await e.json();return{form:r&&o(r)}}async function f(){const t=await fetch("/_workspace");if(t.status!=200)return n({});const e=await t.json();return n(e)}export{f as a,d as g};
//# sourceMappingURL=api.0b487b10.js.map
