import{C as l}from"./Card.b3863c0d.js";import{d as M,N as _,bX as d,f as r,bB as u,H as $,aM as G,co as f}from"./outputWidgets.84fe9cdf.js";import{C as i,A as v}from"./CollapsePanel.d4790a2a.js";import{F as o}from"./Form.ff60b0b9.js";import{T as c,A as b}from"./Timeline.4055cf34.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ab0b0f30-8574-4db3-84ef-0836ef6f12bf",e._sentryDebugIdIdentifier="sentry-dbid-ab0b0f30-8574-4db3-84ef-0836ef6f12bf")}catch{}})();const w=()=>({prefixCls:String,title:u(),description:u(),avatar:u()}),C=M({compatConfig:{MODE:3},name:"ACardMeta",props:w(),slots:Object,setup(e,a){let{slots:n}=a;const{prefixCls:t}=_("card",e);return()=>{const m={[`${t.value}-meta`]:!0},s=d(n,e,"avatar"),I=d(n,e,"title"),g=d(n,e,"description"),A=s?r("div",{class:`${t.value}-meta-avatar`},[s]):null,D=I?r("div",{class:`${t.value}-meta-title`},[I]):null,y=g?r("div",{class:`${t.value}-meta-description`},[g]):null,x=D||y?r("div",{class:`${t.value}-meta-detail`},[D,y]):null;return r("div",{class:m},[A,x])}}}),F=()=>({prefixCls:String,hoverable:{type:Boolean,default:!0}}),p=M({compatConfig:{MODE:3},name:"ACardGrid",__ANT_CARD_GRID:!0,props:F(),setup(e,a){let{slots:n}=a;const{prefixCls:t}=_("card",e),m=$(()=>({[`${t.value}-grid`]:!0,[`${t.value}-grid-hoverable`]:e.hoverable}));return()=>{var s;return r("div",{class:m.value},[(s=n.default)===null||s===void 0?void 0:s.call(n)])}}});l.Meta=C;l.Grid=p;l.install=function(e){return e.component(l.name,l),e.component(C.name,C),e.component(p.name,p),e};i.Panel=v;i.install=function(e){return e.component(i.name,i),e.component(v.name,v),e};o.useInjectFormItemContext=G;o.ItemRest=f;o.install=function(e){return e.component(o.name,o),e.component(o.Item.name,o.Item),e.component(f.name,f),e};c.Item=b;c.install=function(e){return e.component(c.name,c),e.component(b.name,b),e};export{p as G,C as M};
//# sourceMappingURL=index.9fb0e57f.js.map
